### Large Language Models Python API
- ✅ 百度文心一言/ERNIE
- ✅ 阿里通义千问/QWen
- ✅ 讯飞星火大模型/Spark
- ✅ 腾讯混元大模型/Hunyuan
- ✅ DeepSeek

### Install
```shell
pip install chatchat
```

### Usage
```shell
# set YOUR secret keys
# tencent
chatchat config tencent.secret_id=YOUR_SECRET_ID
chatchat config tencent.secret_key=YOUR_SECRET_KEY
# baidu
chatchat config baidu.api_key=YOUR_API_KEY
chatchat config baidu.secret_key=YOUR_SECRET_KEY
# list info of all supported platform
chatchat config --list
```
> Refer to [\[examples\]](./examples)

### Sponsor
<table align="center">
    <thead>
        <tr>
            <th colspan="2">公众号</th>
        </tr>
    </thead>
    <tbody align="center" valign="center">
        <tr>
            <td colspan="2"><img src="https://www.chatqkv.com/ghstatic/images/ofa_m.png" style="height: 196px" alt="AliPay.png"></td>
        </tr>
    </tbody>
    <thead>
        <tr>
            <th>AliPay</th>
            <th>WeChatPay</th>
        </tr>
    </thead>
    <tbody align="center" valign="center">
        <tr>
            <td><img src="https://www.chatqkv.com/AliPay.png" style="width: 196px; height: 196px" alt="AliPay.png"></td>
            <td><img src="https://www.chatqkv.com/WeChatPay.png" style="width: 196px; height: 196px" alt="WeChatPay.png"></td>
        </tr>
    </tbody>
</table>

